// Copyright 2019 autocareai.com. All rights reserved.
// Use of this source code is governed by autocareai.com.

package analysis

import (
	"gadm-ods/apis"
	"gadm-ods/common.in/clinit"
	"gadm-ods/model"
	"fmt"
	"github.com/tidwall/gjson"
	"strings"
)

// zr 全国二要素验证
func ParasOds3(content string) (ret []map[string]string, err error) {
	data := gjson.Parse(content)
	requestParams := data.Get("request_params").String()
	requestParamsArray := gjson.Parse(requestParams).Array()
	if len(requestParamsArray) < 1 {
		return nil, fmt.Errorf("数据异常,没有数据")
	}
	requestParam := requestParamsArray[0]

	plateNo := requestParam.Get("plateNum").String()
	plateColor := requestParam.Get("plateColor").String()
	if plateColor != "" {
		plateColor, _ = ConvertPlateType(plateColor)
	}
	owner := requestParam.Get("name").String()
	//idCard := requestParam.Get("id_number").String()

	responseParams := data.Get("response_params").String()
	code := gjson.Get(responseParams, "code").String()
	if code != "0"{
		return nil , fmt.Errorf("数据异常,code不为0")
	}
	ownerVerifyResult := gjson.Get(responseParams, "data.checkResult").String()


	if plateNo == "" || plateColor == "" || owner == "" {
		return nil, fmt.Errorf("数据异常,车牌姓名不匹配")
	}

	dataMap := make(map[string]string)
	if !strings.Contains(ownerVerifyResult,"2"){
		if strings.Contains(ownerVerifyResult,"5") {
			return nil, fmt.Errorf("数据异常,查无")
		}

		dataMap["is_expire"] = "1"
	}

	dataMap["plate_no"] = plateNo
	dataMap["plate_type"] = plateColor
	dataMap["owner"] = owner
	//dataMap["id_card"] = idCard
	ret = append(ret, dataMap)
	return ret, nil

}

func HandleOnlineOds3(msg *apis.OdsMessage) (dataMapList []map[string]string, err error) {
	dataMapList, err = ParasOds3(msg.Content)
	if err != nil {
		// 解析不出来数据直接返回
		return nil, nil
	}

	if len(dataMapList) == 0 {
		return nil, nil
	}

	// 入本地库
	ods3 := &model.Ods3{}
	ods3.PlateNo = dataMapList[0]["plate_no"]
	ods3.PlateType = dataMapList[0]["plate_type"]
	ods3.Owner = dataMapList[0]["owner"]
	ods3.Content = msg.Content
	err = ods3.Insert(clinit.DB())
	if err != nil {
		if !strings.Contains(err.Error(), "Duplicate") {
			return nil, err
		} else {
			where := map[string]interface{}{"plate_no": ods3.PlateNo, "plate_type": ods3.PlateType, "owner": ods3.Owner}
			oldOds3 := &model.Ods3{}
			err = oldOds3.Query(clinit.DB(), where)
			if err == nil {
				oldDataMapList, _ := ParasOds3(oldOds3.Content)
				if checkDataMapListEqual(oldDataMapList, dataMapList) {
					return nil, nil
				}
			}
			ods3.UpdateWhere(clinit.DB(), where)
		}

	}

	if dataMapList[0]["is_expire"] == "1"{
		return nil, nil
	}

	/*for _, dataMap := range dataMapList {
		dwsMsg := dutils.NewDwsMessage(msg)
		dwsMsg.Content = utils.MarshalJsonString(dataMap)
		ret = append(ret, dwsMsg)
	}*/

	return dataMapList, nil
}
